@@ -20,6 +20,23 @@ sub start {
 	return $self;
 }
 
+sub preprocess_req {
+        my ($self, $req, $t) = @_;
+	if (!$req) {
+		if ($self->controllers->{_alias}) {
+			my $path = $t->request->uri->path;
+			for my $candidate (keys %{$self->controllers->{_alias}}) {
+                        	my @captured = $path =~ m/$candidate/;
+                        	if (scalar @captured) {
+                                	$t->captured = \@captured;
+                                	$t->params->req = $req = $self->controllers->{_alias}->{$candidate}->{req};
+                        	}
+                	}
+		}
+        	($req) = $t->request->uri->path =~ m/([^\/]+)$/ if ! $req;
+	}
+        return $req;
+}
 
 sub _build_models {
 	my ($self, $pkg, $path) =@_; 
@@ -68,7 +85,8 @@ sub _load_modules {
 		$self->raiseError($@) && die $@ if $@;
 		$module = $module->[1]->new(app => 1);
 		die $@ && next if $@;
-		$mods{_alias}{$module->capture} = $module->namespace if $module->{capture}; 	
+		$mods{_alias} = { %{$mods{_alias} || {}}, %{$Terse::Controller::dispatcher{ref $module}{_alias} || {}} }; 
+		$mods{_alias}{$module->capture} = { namespace => $module->namespace } if $module->{capture};
 		$mods{$module->namespace} = $module;
 	}
 	return \%mods;
@@ -99,12 +117,6 @@ sub _recurse_directory {
 	return @files;
 }
 
-sub preprocess_req {
-	my ($self, $req, $t) = @_;
-	($req) = $t->request->uri->path =~ m/([^\/]+)$/ if ! $req;
-	return $req;
-}
-
 sub dispatch {
 	my ($self, $req, $t, @params) = @_;
 	(my $path = $t->request->uri->path) =~ s/^\///g;
@@ -142,7 +154,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.103
+Version 0.104
 
 =cut
 
