@@ -23,6 +23,22 @@ sub new {
 	return $self;
 }
 
+sub preprocess_req {
+	my ($self, $req, $t) = @_;
+	if (!$req) {
+		my $alias = $Terse::Controller::dispatcher{ref $self}{_alias};
+		my $path = $t->request->uri->path;
+		for my $candidate (keys %{$alias}) {
+			my @captured = $path =~ m/$candidate/;
+			if (scalar @captured) {
+				$t->captured = \@captured;
+				$req = $alias->{$candidate}->{req};
+			}
+		}
+	}
+	return $req;
+}
+
 sub build_terse {
 	my ($self, $t) = @_;
 	if ($self->models) {
@@ -35,12 +51,13 @@ sub build_terse {
 	if ($self->controllers) {
 		$t->{controller} = sub {
 			my ($t, $controller) = @_;
-
 			return $self->controllers->{$controller} if $self->controllers->{$controller};
+			return $self->controllers->{$self->controllers->{_alias}->{$controller}->{namespace}}
+				if $self->controllers->{_alias}->{$controller};
 			for my $key (keys %{$self->controllers->{_alias}}) {
 				my @captured = $controller =~ m/$key/;
 				if (scalar @captured) {
-					$controller = $self->controllers->{$self->controllers->{_alias}->{$key}};
+					$controller = $self->controllers->{$self->controllers->{_alias}->{$key}->{namespace}};
 					$t->captured = \@captured;
 					return $controller;
 				}
@@ -63,6 +80,14 @@ sub MODIFY_CODE_ATTRIBUTES {
 	my $name = svref_2object($coderef)->GV->NAME;
 	my %attr = PARSE_ATTRIBUTES($name, @attributes);
 	push @{ $Terse::Controller::dispatcher{$package}{$attr{req}} }, \%attr;
+	if ($attr{path}) {
+		(my $namespace = $package) =~ s/^.*Controller:://;
+		$namespace =~ s/\:\:/\//g;
+		$Terse::Controller::dispatcher{$package}{_alias}{$attr{path}} = {
+			namespace => lc( $namespace ),
+			req => $attr{req}
+		};
+	}
 	return ();
 }
 
@@ -85,7 +110,7 @@ sub PARSE_ATTRIBUTES {
 		elsif ($attribute =~ m/^\s*([^\s\(]+)\s*\(([\s\'\"]*?)(.*)([\s\'\"]*?)\)/) {
 			my $k = lc($1);
 			$attr{$k} = $3;
-			if ($HTTP{$k}) {
+			if ($HTTP{$k} || $k eq 'any') {
 				$attr{req} = $3;
 			}	
 		}
@@ -116,11 +141,8 @@ sub dispatch {
 		$t->logError('Invalid dispatch request', 400);
 		return;
 	}
-	if (!$self->{app} && $t->request->uri->path ne $self->restrict_path) {
-		$t->logError('Invalid path', 500);
-		return;
-	}
 	my $dispatch;
+	my $path = $t->request->uri->path;
 	DISPATCH: for my $candidate (reverse @{$dispatcher}) {
 		next DISPATCH unless ($candidate->{lc($t->request->method)} || $candidate->{any});
 		if ($candidate->{params}) {
@@ -175,7 +197,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.103
+Version 0.104
 
 =cut
 
@@ -213,6 +235,11 @@ Version 0.103
 		... # 4
 	}
 
+	sub other :get :path(foo/bar) {
+		... # 5
+	}
+
+
 	1;
 
 	.... psgi ...
@@ -239,6 +266,8 @@ Version 0.103
 	GET http://localhost:5000/?req=purchase&virtual=1 #2
 	POST http://localhost:5000/ {"req":"purchase", "virtual":1} #4
 
+	GET http://localhost:5000/foo/bar #5
+
 =cut
 
 =head1 AUTHOR
