@@ -4,8 +4,8 @@ use base 'Terse::Controller';
 
 sub build_controller {
 	my ($self) = @_;
-	$self->required_captured = 2;
-	$self->capture = 'app/(.*)/hello/(.*)';
+	#$self->required_captured = 2;
+	#$self->capture = 'app/(.*)/hello/(.*)';
 	return $self;
 }
 
@@ -18,7 +18,7 @@ sub hello :get {
 	$_[1]->response->hello = $_[1]->model('test')->something();
 }
 
-sub hello_get :get(hello_world) {
+sub hello_get :get :path(app/(.*)/hello/world) {
 	$_[1]->response->hello = "world 2";
 }
 
