@@ -27,11 +27,11 @@ sub auth_okay :req(auth) :get :post  {
 	return 1;
 }
 
-sub hello :any(hello_world) {
+sub hello :any(hello_world) :path(hello/world) {
 	$_[1]->response->hello = "world";
 }
 
-sub hello_get :get(hello_world) {
+sub hello_get :get :path(hello/get) {
 	$_[1]->response->hello = $_[1]->model('test')->something;
 }
 
